@@ -35,16 +35,20 @@
 
 #include <gst/gst.h>
 
+#include <libgnomeui/libgnomeui.h>
+
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
 
 #include <nautilus-burn-recorder.h>
 #include <nautilus-burn-init.h>
 
 #include <gconf/gconf-client.h>
 
+#ifdef HAVE_LIBNOTIFY
+#include <libnotify/notify.h>
+#endif
+
 #include "brasero-app.h"
 #include "menu.h"
 #include "brasero-multi-dnd.h"
@@ -52,6 +56,8 @@
 #include "brasero-sum-dialog.h"
 #include "brasero-session.h"
 #include "brasero-project-manager.h"
+#include "brasero-ncb.h"
+#include "burn-debug.h"
 
 static GConfClient *client;
 gchar *project_uri;
@@ -233,7 +239,7 @@ on_about_cb (GtkAction *action, BraseroApp *app)
 			       "copyright", "Copyright © 2006 Philippe Rouquier",
 			       "authors", authors,
 			       "documenters", documenters,
-			       "website", "http://perso.orange.fr/bonfire/",
+			       "website", "http://www.gnome.org/projects/brasero",
 			       "website-label", _("Brasero Homepage"),
 			       "license", license,
 			       "wrap-license", TRUE,
@@ -559,11 +565,17 @@ main (int argc, char **argv)
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
 
-	nautilus_burn_init ();
+#ifdef HAVE_LIBNOTIFY
+	notify_init (PACKAGE);
+#endif
 
+	nautilus_burn_init ();
 	gnome_vfs_init ();
 	gst_init (&argc, &argv);
 
+	brasero_burn_set_debug (debug);
+	NCB_INIT ();
+
 	client = gconf_client_get_default ();
 
 	brasero_enable_multi_DND ();
